@@ -1,7 +1,9 @@
 import requests
-from typing import Dict
 import urllib3
-urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
+
+urllib3.disable_warnings(
+    urllib3.exceptions.InsecureRequestWarning
+)  # disable ssl warning
 
 
 class REST:
@@ -76,8 +78,8 @@ class REST:
     def get_conid(
         self,
         symbol: str,
-        instrument_filters: Dict = None,
-        contract_filters: Dict = {"isUS": True},
+        instrument_filters: dict = None,
+        contract_filters: dict = {"isUS": True},
     ) -> int:
         """Returns contract id of the given stock instrument
 
@@ -99,8 +101,8 @@ class REST:
 
         if instrument_filters or contract_filters:
 
-            def filter_instrument(instrument: Dict) -> bool:
-                def apply_filters(x: Dict, filters: Dict) -> list:
+            def filter_instrument(instrument: dict) -> bool:
+                def apply_filters(x: dict, filters: dict) -> list:
                     positives = list(
                         filter(
                             lambda x: x,
@@ -188,6 +190,8 @@ class REST:
             verify=self.ssl,
         )
 
+        assert response.status_code == 200, response.json()
+
         return self._reply_all_yes(response, reply_yes)
 
     def get_order(self, orderId: str) -> dict:
